tkmilan
=======

.. automodule:: tkmilan

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      MODULES_VERBOSE
      varOrientation
      AUTO
      HORIZONTAL
      VERTICAL
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      Combobox
      ComboboxMap
      ComboboxRaw
      Entry
      LOGGING_VERBOSE
      SeparatorH
      SeparatorV
      Spinbox
      SpinboxNum
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Button
      Canvas
      Checkbox
      CheckboxFrame
      ComboboxN
      EntryMultiline
      EntryN
      EntryRaw
      FrameLabelled
      FramePaned
      FrameRadio
      FrameStateful
      FrameUnlabelled
      Label
      LabelStateful
      Listbox
      ListboxControl
      Notebook
      NotebookUniform
      Radio
      RootWindow
      ScrolledWidget
      SecondaryWindow
      Separator
      SpinboxN
      Tree
      varTree
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   tkmilan.autolayout
   tkmilan.bg
   tkmilan.diagram
   tkmilan.drender
   tkmilan.exception
   tkmilan.fn
   tkmilan.mixin
   tkmilan.model
   tkmilan.parser
   tkmilan.util
   tkmilan.validation
   tkmilan.var

